DOMNodeRuntimeDartHTMLImpl class

Inheritance

Constructors

DOMNodeRuntimeDartHTMLImpl(DOMTreeMap<Node>? treeMap, DOMNode? domNode, Node? node)

Properties

children → List<Node>
Returns the List of children nodes.
no setteroverride
classes → List<String>
Returns the classes of this node.
no setteroverride
domGenerator → DOMGenerator<Node>
The DOMGenerator used to generate this treeMap.
no setterinherited
domNode → DOMNode?
The DOMNode of this node.
finalinherited
exists → bool
Returns true if this node and domNode exists.
no setterinherited
hashCode → int
The hash code for this object.
no setterinherited
hasParent → bool
Returns true if this node has a parent.
no setterinherited
indexInParent → int
no setteroverride
isNodeElement → bool
no setter
isStringElement → bool
Returns true if this node is a String element (a Text node or DOMElement.isStringTagName).
no setteroverride
node → Node?
The runtime node (generated element/node).
finalinherited
nodeAsElement → Element?
no setter
nodesLength → int
Returns the number of children nodes.
no setteroverride
parent → Node?
This node parent.
no setterinherited
parentRuntime → DOMNodeRuntime<Node>?
The DOMNodeRuntime of parent.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
style ↔ CSS
Gets runtime style of node as CSS.
getter/setter pairinherited
tagName → String?
The tag name of this node.
no setteroverride
text ↔ String
Returns the text of this node.
getter/setter pairoverride
treeMap → DOMTreeMap<Node>?
finalinherited
value ↔ String?
getter/setter pairoverride

Methods

absorbNode(Node? other) → bool
override
add(Node child) → void
Adds child node.
override
addClass(String? className) → void
Adds a className to this node classes.
override
clear() → void
override
clearClasses() → void
Clears classes from this node classes.
override
copy() → Element
Copies this node.
override
duplicate() → Node?
Duplicates this node, inserting it at parent.
inherited
getAttribute(String name) → String?
Returns the value of the attribute of name.
override
getNodeAt(int index) → Node?
Returns the node at index.
override
getSiblingRuntime(Node? other) → DOMNodeRuntime<Node>?
inherited
getStyleEntry(String name) → CSSEntry<CSSValue>?
Gets a runtime style CSSEntry for name from node.
inherited
getStyleProperty(String name) → String?
Gets a runtime style property for name from node.
inherited
indexOf(Node child) → int
Returns the index of child.
override
insertAt(int index, Node? child) → void
Inserts child node at index.
override
isConsecutiveNode(Node other) → bool
inherited
isInSameParent(Node other) → bool
Returns true if other is in the same parent of this node.
override
isNextNode(Node? other) → bool
inherited
isPreviousNode(Node? other) → bool
inherited
mergeNode(Node? other, {bool onlyConsecutive = true}) → bool
inherited
moveDown() → bool
Moves this node down in parent's children.
inherited
moveUp() → bool
Moves this node up in parent's children.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
remove() → bool
Removes this node.
override
removeAt(int index) → Node?
Removes child node at index.
override
removeAttribute(String name) → void
Removes the attribute of name.
override
removeClass(String? className) → bool
Removes className from this node classes.
override
removeNode(Node? child) → bool
Removes child node.
override
removeStyleEntries(List<String> names) → List<CSSEntry<CSSValue>>
inherited
removeStyleEntry(String name) → CSSEntry<CSSValue>?
inherited
removeStyleProperties(List<String> names) → Map<String, String>
inherited
removeStyleProperty(String name) → String?
inherited
replaceBy(List? elements, {bool remap = false}) → bool
Replaces this node with elements.
inherited
setAttribute(String name, String value) → void
Sets the value of the attribute of name.
override
setStyleProperties(Map<String, String> properties) → void
inherited
setStyleProperty(String name, String value) → String?
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited
operator [](String name) → String?
inherited
operator []=(String name, Object? value) → void
inherited